package com.inteligr8.junit4;

import java.util.Collection;

import org.junit.Assert;

/**
 * This class implements JUnit4 assertion methods focused on collections.
 * 
 * @author brian@inteligr8.com
 */
public class AssertCollection {
	
	/**
	 * This method evaluates the size of a collection.
	 * 
	 * @param expectedCount The expected size of the collection
	 * @param actualCollection The collection to evaluate
	 */
	public static void assertSize(int expectedCount, Collection<?> actualCollection) {
		assertSize(null, expectedCount, actualCollection);
	}
	
	/**
	 * This method evaluates the size of a collection.
	 * 
	 * @param message A message to record on failure
	 * @param expectedCount The expected size of the collection
	 * @param actualCollection The collection to evaluate
	 */
	public static void assertSize(String message, int expectedCount, Collection<?> actualCollection) {
		if (expectedCount == 0) Assert.assertTrue(message, actualCollection == null || actualCollection.isEmpty());
		else Assert.assertTrue(message, actualCollection != null && actualCollection.size() == expectedCount);
	}
	
	/**
	 * This method evaluates the contents of a collection
	 * 
	 * @param expectedElement A expected element in the collection
	 * @param actualCollection A collection to search/inspect
	 */
	public static <T> void assertContains(T expectedElement, Collection<T> actualCollection) {
		assertContains(null, expectedElement, actualCollection);
	}
	
	/**
	 * This method evaluates the contents of a collection
	 * 
	 * @param expectedElements A subset of the expected elements in the collection
	 * @param actualCollection A collection to search/inspect
	 */
	public static <T> void assertContains(Collection<T> expectedElements, Collection<T> actualCollection) {
		assertContains(null, expectedElements, actualCollection);
	}
	
	/**
	 * This method evaluates the contents of a collection
	 * 
	 * @param message A message to record on failure
	 * @param expectedElement A expected element in the collection
	 * @param actualCollection A collection to search/inspect
	 */
	public static <T> void assertContains(String message, T expectedElement, Collection<T> actualCollection) {
		Assert.assertTrue(message, actualCollection != null && actualCollection.contains(expectedElement));
	}
	
	/**
	 * This method evaluates the contents of a collection
	 * 
	 * @param message A message to record on failure
	 * @param expectedElements A subset of the expected elements in the collection
	 * @param actualCollection A collection to search/inspect
	 */
	public static <T> void assertContains(String message, Collection<T> expectedElements, Collection<T> actualCollection) {
		Assert.assertTrue(message, actualCollection != null && actualCollection.containsAll(expectedElements));
	}

}
